"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultAmplify = void 0;
var tslib_1 = require("tslib");
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
var core_1 = require("@aws-amplify/core");
var utils_1 = require("@aws-amplify/core/internals/utils");
var cognito_1 = require("./auth/cognito");
exports.DefaultAmplify = {
    configure: function (resourceConfig, libraryOptions) {
        var resolvedResourceConfig;
        if (Object.keys(resourceConfig).some(function (key) { return key.startsWith('aws_'); })) {
            resolvedResourceConfig = (0, utils_1.parseAWSExports)(resourceConfig);
        }
        else {
            resolvedResourceConfig = resourceConfig;
        }
        // When Auth config is provided but no custom Auth provider defined
        // use the default Auth Providers
        if (resolvedResourceConfig.Auth && !(libraryOptions === null || libraryOptions === void 0 ? void 0 : libraryOptions.Auth)) {
            cognito_1.CognitoUserPoolsTokenProvider.setAuthConfig(resolvedResourceConfig.Auth);
            var libraryOptionsWithDefaultAuthProviders = tslib_1.__assign(tslib_1.__assign({}, libraryOptions), { Auth: {
                    tokenProvider: cognito_1.CognitoUserPoolsTokenProvider,
                    credentialsProvider: cognito_1.cognitoCredentialsProvider,
                } });
            cognito_1.CognitoUserPoolsTokenProvider.setKeyValueStorage((libraryOptions === null || libraryOptions === void 0 ? void 0 : libraryOptions.ssr)
                ? new core_1.CookieStorage({
                    sameSite: 'strict',
                })
                : core_1.defaultStorage);
            core_1.Amplify.configure(resolvedResourceConfig, libraryOptionsWithDefaultAuthProviders);
        }
        else {
            core_1.Amplify.configure(resolvedResourceConfig, libraryOptions);
        }
    },
    getConfig: function () {
        return core_1.Amplify.getConfig();
    },
};
